@@ -14,7 +14,10 @@ from onnx2tf.utils.common_functions import (
     make_tf_node_info,
     pre_process_transpose,
     post_process_transpose,
+    make_tf_partial_model_inputs,
+    dummy_tf_inference,
 )
+from typing import Any, Dict, List
 
 
 @print_node_info
@@ -93,10 +96,26 @@ def make_node(
             before_op_output_shape_trans=before_op_output_shape_trans,
         ) for idx in range(tensor_rank)
     ]
+
+    # NHWC -> HCHW
     transposed_tensor = tf.transpose(
         a=input_tensor,
         perm=list(perm) if perm is not None else None,
     )
+    test_data = None
+    if not isinstance(input_tensor, np.ndarray):
+        if not isinstance(graph_node_input_1, np.ndarray) \
+            and 'verification_data' in tf_layers_dict[graph_node_input_1.name].keys():
+            test_data: np.ndarray = tf_layers_dict[graph_node_input_1.name]['verification_data']
+            test_data = test_data.transpose(list(perm) if perm is not None else None)
+        elif isinstance(graph_node_input_1, np.ndarray):
+            test_data: np.ndarray = input_tensor
+            test_data = test_data.transpose(list(perm) if perm is not None else None)
+        else:
+            test_data = None
+    else:
+        test_data = input_tensor.transpose(list(perm) if perm is not None else None)
+
     if isinstance(reshape_shape, np.ndarray):
         perm_shape = [
             convert_axis(
@@ -135,12 +154,21 @@ def make_node(
         **kwargs,
     )
 
+    # Generate input OPs for TensorFlow subgraphs
+    # For inference testing on OP stand-alone
+    tf_partial_model_inputs: List[tf.keras.Input] = \
+        make_tf_partial_model_inputs(
+            input_tensors=[transposed_tensor]
+        )
+    tf_partial_model_outputs = None
+
     # Reshape
     has_undefined_outputshape = output_shape is None
     if not has_undefined_outputshape:
         has_none_outputshape = None in output_shape
         has_str_outputshape = True in [True for dim in output_shape if isinstance(dim, str)]
         has_undefined_outputshape = has_none_outputshape or has_str_outputshape
+    ### Overall model
     tf_layers_dict[graph_node_output.name]['tf_node'] = \
         tf.reshape(
             tensor=transposed_tensor,
@@ -148,6 +176,33 @@ def make_node(
                 if has_undefined_outputshape else output_shape,
             name=graph_node.name,
         )
+    ### Partial model
+    if tf_partial_model_inputs is not None:
+        tf_partial_model_outputs = \
+            [
+                tf.reshape(
+                    tensor=tf_partial_model_inputs[0],
+                    shape=transposed_reshape_shape \
+                        if has_undefined_outputshape else output_shape,
+                )
+            ]
+        tf_partial_model = tf.keras.Model(
+            inputs=tf_partial_model_inputs,
+            outputs=tf_partial_model_outputs,
+        )
+        tf_partial_model_result_infos: Dict[Any] = dummy_tf_inference(
+            model=tf_partial_model,
+            inputs=tf_partial_model_inputs,
+            verification_datas=[
+                test_data
+            ]
+        )
+        tf_layers_dict[graph_node_output.name]['verification_data'] = \
+            list(tf_partial_model_result_infos.values())[0]
+        del tf_partial_model
+        del tf_partial_model_inputs
+        del tf_partial_model_outputs
+        del test_data
 
     # Special support for ShuffleNet patterns
     # 5D Reshape -> 5D Transpose -> 4D Reshape
@@ -172,17 +227,21 @@ def make_node(
                 and two_previous_op_output_shape[2] == one_previous_op_output_shape[1] \
                 and current_op_output_shape[1] == (one_previous_op_output_shape[1] * one_previous_op_output_shape[2]):
                 # ShuffleNet patterns - 4D only
+                ### Overall model
                 tf_layers_dict[graph_node_output.name]['tf_node'] = \
                     tf.transpose(
                         a=tf_layers_dict[graph_node_output.name]['tf_node'],
                         perm=[0,2,3,1],
                     )
+                ### Partial model
+                if tf_partial_model_inputs is not None:
+                    tf_layers_dict[graph_node_output.name]['verification_data'] = \
+                        tf_layers_dict[graph_node_output.name]['verification_data'].transpose([0,2,3,1])
             else:
                 pass
     except:
         pass
 
-
     # Post-process transpose
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
         value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
